spoon.transports.transporthub.SpoonRPCHello

Package spoon :: Package transports :: Module transporthub :: Class SpoonRPCHello |
[hide private]
[frames] | no frames]

# Class SpoonRPCHello

source code

    Serial --+
             |
            SpoonRPCHello

This object is sent as a very simple form of initial negotiation. It contains the nodeId and the protocol version (currently always 1.)

Class Variables | [hide private]
`` | nodeId = `serialprop()`
`` | version = `serialprop(1)`

Class Variable Details | [hide private]

    ### nodeId None Value:
        serialprop()

    ### version None Value:
        serialprop(1)